/***************************************************************************
                          alertdialog.h  -  description
                             -------------------
    begin                : Sun Nov 4 2001
    copyright            : (C) 2001 by Eggert Ehmke
    email                : eggert.ehmke@berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ALERTDIALOG_H
#define ALERTDIALOG_H

#include <tqwidget.h>
#include "AlertDlg.h"

/**
  *@author Eggert Ehmke
  */

class AlertDialog : public AlertDlg
{
   Q_OBJECT
public:
	AlertDialog(TQWidget *parent=0, const char *name=0);
	~AlertDialog();
public slots:
	void slotOk ();
signals:
	void signalOk ();
};

#endif
